import _ from 'lodash'
import { Component, View } from 'angular2/core'
import {Router, RouteParams} from 'angular2/router'
import ShipService from './service'
import ShipForm from './form'
import SaveButton from '../common/save-button'
import Alert from '../common/alert/service'

@Component({
  selector: 'ship-new',
  providers: [ShipService, Alert]
})
@View({
  directives: [ShipForm, SaveButton],
  template: `
  <h1>New Ship</h1>
  <ship-form [ship]="ship" (formData)="handleFormUpdate($event)">
    <button type="button" class="btn btn-secondary" (click)="handleCancel()"><i class="fa fa-ban"></i> Cancel</button>
    <save-button id="create" (click)="handleSave()" name="Save" [isSaving]="isSaving" [disableSave]="disableSave"></save-button>
  </ship-form>
`
})
export default class ShipNew {
  constructor (service: ShipService, router: Router, params: RouteParams, alert: Alert) {
    this.alert = alert
    this.id = params.get('id')
    this.service = service
    this.router = router
    this.ship = {}
    service
      .getShip(this.id)
      .subscribe(res => this.ship = res)
  }
  handleFormUpdate (data) {
    this.formData = data
    let isValid = this.ship.isValid(data)
    this.disableSave = !isValid
  }
  handleCancel () {
    this.router.navigate(['/ShipView', {id: this.id}])
  }
  handleSave ($event) {
    this.isSaving = true
    let data = _.assign({}, this.formData, {_id: this.id})
    this.service
      .saveShip(data)
      .subscribe(res => {
        this.router.navigate(['/ShipView', {id: res._id}])
      }, err => {
        this.isSaving = false
        console.error(err)
        this.alert.show('Error saving Ship')
      })
  }
}
