import {Component, View, EventEmitter} from 'angular2/core'
import {FORM_DIRECTIVES, NgIf, NgClass, FormBuilder} from 'angular2/common'

import {VALIDATORS} from './ship'

function titleValidator (c) {
  let isValid = VALIDATORS.title(c.value)
  return isValid ? null : {notValid: 'Title is not valid'}
}

@Component({
  selector: 'ship-form',
  inputs: ['ship'],
  outputs: ['formData']
})
@View({
  directives: [FORM_DIRECTIVES, NgIf, NgClass],
  template: `
  <form #f="ngForm" class="mean-form" [ngFormModel]="shipForm">
  <section class="inputs">
    <fieldset class="one-col">
      <label for="title">Title</label>
      <input type="text" id="title" [ngModel]="ship.title" ngControl="title">
    </fieldset>
    <fieldset class="one-col">
      <label for="description">Description</label>
      <textarea id="description" [ngModel]="ship.description" ngControl="description"></textarea>
    </fieldset>
    <fieldset class="one-col checkbox">
      <label for="hyperdrive">
        <input type="checkbox" id="hyperdrive" [ngModel]="ship.hyperdrive" ngControl="hyperdrive" /> Hyper Drive
      </label>
    </fieldset>
    <fieldset class="one-col checkbox">
      <label for="shields">
        <input type="checkbox" id="shields" [ngModel]="ship.shieldGenerator" ngControl="shieldGenerator" /> Shield Generator
      </label>
    </fieldset>
    <fieldset class="one-col checkbox">
      <label for="cannons">
        <input type="checkbox" id="cannons" [ngModel]="ship.cannons" ngControl="cannons" /> Cannons
      </label>
    </fieldset>
    </section>
    <ng-content></ng-content>
  </form>
`
})
export default class ShipForm {
  constructor (fb: FormBuilder) {
    this.shipForm = fb.group({
      cannons: [''],
      shieldGenerator: [''],
      hyperdrive: [''],
      description: [''],
      title: ['', titleValidator]
    })
    this.title = this.shipForm.controls['title']
    this.formData = new EventEmitter()
    this.shipForm.valueChanges.subscribe(change => {
      if (!this.ship.isValid) return
      this.formData.next(change)
    })
  }
}
