import { Component, View } from 'angular2/core'
import {Router} from 'angular2/router'
import ShipService from './service'
import {Ship} from './ship'
import ShipForm from './form'
import SaveButton from '../common/save-button'

@Component({
  selector: 'ship-new',
  providers: [ShipService]
})
@View({
  directives: [ShipForm, SaveButton],
  template: `
  <h1>New Ship</h1>
  <ship-form [ship]="ship" (formData)="handleFormUpdate($event)">
    <button type="button" class="btn btn-secondary" (click)="handleCancel()"><i class="fa fa-ban"></i> Cancel</button>
    <save-button id="create" (click)="handleSave()" name="Create" [isSaving]="isSaving" [disableSave]="disableSave"></save-button>
  </ship-form>
`
})
export default class ShipNew {
  constructor (service: ShipService, router: Router) {
    this.service = service
    this.ship = new Ship()
    this.router = router
  }
  handleFormUpdate (data) {
    this.formData = data
    let isValid = this.ship.isValid(data)
    this.disableSave = !isValid
  }
  handleCancel () {
    this.router.navigate(['/Ships'])
  }
  handleSave ($event) {
    this.isSaving = true
    this.service
      .createShip(this.formData)
      .subscribe(res => {
        this.router.navigate(['/ShipView', {id: res._id}])
      }, err => {
        this.isSaving = false
        console.error(err)
        this.alert.show('Error saving new Ship')
      })
  }
}
