import { Component, View } from 'angular2/core'
import {NgClass} from 'angular2/common'
import {ROUTER_DIRECTIVES, RouteParams, Router} from 'angular2/router'
import ShipService from './service'

@Component({
  selector: 'ship-view',
  providers: [ShipService]
})
@View({
  directives: [ROUTER_DIRECTIVES, NgClass],
  template: `
  <h1>{{ship.title}}
  <button type="button" (click)="handleClick($event)" class="btn btn-primary"><i class="fa fa-edit fa-lg"></i></button>
  </h1>
  <p>{{ship.description}}</p>
  <h2>Options</h2>
  <ul>
    <li>Hyper Drive: <i class="fa" [ngClass]="{'fa-remove': !ship.hyperdrive, 'fa-check': ship.hyperdrive}"></i></li>
    <li>Shield Generator: <i class="fa" [ngClass]="{'fa-remove': !ship.shieldGenerator, 'fa-check': ship.shieldGenerator}"></i></li>
    <li>Cannons: <i class="fa" [ngClass]="{'fa-remove': !ship.cannons, 'fa-check': ship.cannons}"></i></li>
  </ul>
`
})
export default class ShipView {
  constructor (params: RouteParams, router: Router, service: ShipService) {
    this.id = params.get('id')
    this.router = router
    this.ship = {}
    this.service = service
    this.hyperIcon = 'fa-remove'
    service
      .getShip(this.id)
      .subscribe(
        res => this.ship = res,
        err => {
          console.error(err)
          if (err.status === 401) this.router.navigate(['/Login'])
        }
      )
  }

  handleClick ($event) {
    this.router.navigate(['/ShipEdit', {id: this.id}])
  }
}
