import _ from 'lodash'
import { Component, View } from 'angular2/core'
import {Router, RouteParams} from 'angular2/router'
import WeaponService from './service'
import WeaponForm from './form'
import SaveButton from '../common/save-button'
import Alert from '../common/alert/service'

@Component({
  selector: 'weapon-new',
  providers: [WeaponService, Alert]
})
@View({
  directives: [WeaponForm, SaveButton],
  template: `
  <h1>New Weapon</h1>
  <weapon-form [weapon]="weapon" (formData)="handleFormUpdate($event)">
    <button type="button" class="btn btn-secondary" (click)="handleCancel()"><i class="fa fa-ban"></i> Cancel</button>
    <save-button id="create" (click)="handleSave()" name="Save" [isSaving]="isSaving" [disableSave]="disableSave"></save-button>
  </weapon-form>
`
})
export default class WeaponEdit {
  constructor (service: WeaponService, router: Router, params: RouteParams, alert: Alert) {
    this.alert = alert
    this.id = params.get('id')
    this.service = service
    this.router = router
    this.weapon = {}
    service
      .getWeapon(this.id)
      .subscribe(res => this.weapon = res)
  }
  handleFormUpdate (data) {
    this.formData = data
    let isValid = this.weapon.isValid(data)
    this.disableSave = !isValid
  }
  handleCancel () {
    this.router.navigate(['/WeaponView', {id: this.id}])
  }
  handleSave ($event) {
    this.isSaving = true
    let data = _.assign({}, this.formData, {_id: this.id})
    this.service
      .saveWeapon(data)
      .subscribe(res => {
        this.router.navigate(['/WeaponView', {id: res._id}])
      }, err => {
        this.isSaving = false
        console.error(err)
        this.alert.show('Error saving Weapon')
      })
  }
}
