import {Component, View, EventEmitter} from 'angular2/core'
import {FORM_DIRECTIVES, NgIf, NgClass, FormBuilder} from 'angular2/common'

import {VALIDATORS} from './weapon'

function titleValidator (c) {
  let isValid = VALIDATORS.title(c.value)
  return isValid ? null : {notValid: 'Title is not valid'}
}

@Component({
  selector: 'weapon-form',
  inputs: ['weapon'],
  outputs: ['formData']
})
@View({
  directives: [FORM_DIRECTIVES, NgIf, NgClass],
  template: `
  <form #f="ngForm" class="mean-form" [ngFormModel]="weaponForm">
  <section class="inputs">
    <fieldset class="one-col">
      <label for="title">Title</label>
      <input type="text" id="title" [ngModel]="weapon.title" ngControl="title">
    </fieldset>
    <fieldset class="one-col">
      <label for="description">Description</label>
      <textarea id="description" [ngModel]="weapon.description" ngControl="description"></textarea>
    </fieldset>
    </section>
    <ng-content></ng-content>
  </form>
`
})
export default class WeaponForm {
  constructor (fb: FormBuilder) {
    this.weaponForm = fb.group({
      cannons: [''],
      shieldGenerator: [''],
      hyperdrive: [''],
      description: [''],
      title: ['', titleValidator]
    })
    this.title = this.weaponForm.controls['title']
    this.formData = new EventEmitter()
    this.weaponForm.valueChanges.subscribe(change => {
      if (!this.weapon.isValid) return
      this.formData.next(change)
    })
  }
}
