import { Component, View } from 'angular2/core'
import {Router} from 'angular2/router'
import WeaponService from './service'
import {Weapon} from './weapon'
import WeaponForm from './form'
import SaveButton from '../common/save-button'

@Component({
  selector: 'weapon-new',
  providers: [WeaponService]
})
@View({
  directives: [WeaponForm, SaveButton],
  template: `
  <h1>New Weapon</h1>
  <weapon-form [weapon]="weapon" (formData)="handleFormUpdate($event)">
    <button type="button" class="btn btn-secondary" (click)="handleCancel()"><i class="fa fa-ban"></i> Cancel</button>
    <save-button id="create" (click)="handleSave()" name="Create" [isSaving]="isSaving" [disableSave]="disableSave"></save-button>
  </weapon-form>
`
})
export default class WeaponNew {
  constructor (service: WeaponService, router: Router) {
    this.service = service
    this.weapon = new Weapon()
    this.router = router
  }
  handleFormUpdate (data) {
    this.formData = data
    let isValid = this.weapon.isValid(data)
    this.disableSave = !isValid
  }
  handleCancel () {
    this.router.navigate(['/Weapons'])
  }
  handleSave ($event) {
    this.isSaving = true
    this.service
      .createWeapon(this.formData)
      .subscribe(res => {
        this.router.navigate(['/WeaponView', {id: res._id}])
      }, err => {
        this.isSaving = false
        console.error(err)
        this.alert.show('Error saving new Weapon')
      })
  }
}
