import {Component, View, EventEmitter} from 'angular2/core'
import {FORM_DIRECTIVES, NgIf, NgClass, FormBuilder} from 'angular2/common'

import {VALIDATORS} from './master'

function emailValidator (c) {
  let isValid = VALIDATORS.email(c.value)
  return isValid ? null : {notValid: 'Email address is not valid'}
}

function nameValidator (c) {
  let isValid = VALIDATORS.firstName(c.value)
  return isValid ? null : { nameReq: 'Name Required' }
}

@Component({
  selector: 'master-form',
  inputs: ['master'],
  outputs: ['formData']
})
@View({
  directives: [FORM_DIRECTIVES, NgIf, NgClass],
  template: `
  <form #f="ngForm" class="master-form" [ngFormModel]="masterForm">
  <section class="inputs">
    <fieldset class="master-firstname">
      <label for="firstname">First Name</label>
      <input type="text" id="firstName" [ngModel]="master.firstName" ngControl="firstName">
      <small class="text-danger" *ngIf="firstName.errors">{{firstName.errors && firstName.errors.nameReq}}</small>
    </fieldset>
    <fieldset class="master-lastname">
      <label for="lastname">Last Name</label>
      <input type="text" id="lastName" [ngModel]="master.lastName" ngControl="lastName">
    </fieldset>
    <fieldset class="master-origin">
      <label for="planet">Planet of Origin</label>
      <input type="text" id="planet" [ngModel]="master.origin" ngControl="origin">
    </fieldset>
    <fieldset class="master-email">
      <label for="email">Email</label>
      <input type="text" id="email" [ngModel]="master.email" ngControl="email">
      <small class="text-danger" *ngIf="email.errors">{{email.errors && email.errors.notValid}}</small>
    </fieldset>
    </section>
    <ng-content></ng-content>
  </form>
`
})
export default class MasterForm {
  constructor (fb: FormBuilder) {
    this.masterForm = fb.group({
      firstName: ['', nameValidator],
      lastName: [''],
      origin: [''],
      email: ['', emailValidator]
    })
    this.email = this.masterForm.controls['email']
    this.firstName = this.masterForm.controls['firstName']
    this.formData = new EventEmitter()
    this.masterForm.valueChanges.subscribe(change => {
      if (!this.master.isValid) return
      this.formData.next(change)
    })
  }
}
