import {Component, View} from 'angular2/core'
import {RouterLink} from 'angular2/router'
import {COMMON_DIRECTIVES} from 'angular2/common'

import Alert from './alert'
import TokenService from '../users/token'

@Component({
  selector: 'navbar',
  providers: [TokenService]
})
@View({
  directives: [RouterLink, Alert, COMMON_DIRECTIVES],
  template: `
    <nav class="navbar navbar-dark bg-inverse">
      <a class="navbar-brand" [routerLink]="['/Home']">Mastering MEAN</a>
      <ul class="nav navbar-nav hidden-sm-down">
        <li class="nav-item">
          <a class="nav-link" [routerLink]="['/Masters']">Masters <alert num="1"></alert></a>
        </li>
        <li class="nav-item">
          <a class="nav-link" [routerLink]="['/Weapons']">Weapons <alert num="15"></alert></a>
        </li>
        <li class="nav-item">
          <a class="nav-link" [routerLink]="['/Ships']">Ships</a>
        </li>
      </ul>
      <ul class="nav navbar-nav pull-right">
        <li class="nav-item hidden-sm-down">
          <a *ngIf="!isLoggedIn" class="nav-link" [routerLink]="['/Login']">Login</a>
          <a *ngIf="isLoggedIn" class="nav-link" [routerLink]="['/Profile', {id: userId}]">Profile</a>
        </li>
        <li class="nav-item hidden-sm-down">
          <a *ngIf="isLoggedIn" class="nav-link" href="#" (click)="logout()">Logout</a>
          <a *ngIf="!isLoggedIn" class="nav-link" [routerLink]="['/Signup']">Signup</a>
        </li>
        <li class="nav-item hidden-md-up">
          <button type="button" (click)="onClick()" class="btn btn-secondary-online"><i class="fa fa-bars"></i></button>
        </li>
      </ul>
    </nav>
  `
})
export default class NavBar {
  constructor (token: TokenService) {
    this.token = token
    this.isLoggedIn = false
    this.userId = null
    token
      .getOb()
      .subscribe(res => {
        this.isLoggedIn = res.isLoggedIn
        this.userId = res.id
      })
  }
  logout () {
    this.token.removeUserData()
  }
}
