import './style.scss'
import 'zone.js/lib/browser/zone-microtask'
import 'reflect-metadata'
import 'babel-core/polyfill'

import {
  Component, View,
  provide,
  bootstrap
} from 'angular2/angular2'
import {
  Route, RouteConfig,
  LocationStrategy, HashLocationStrategy,
  ROUTER_PROVIDERS, ROUTER_DIRECTIVES, ROUTER_PRIMARY_COMPONENT
} from 'angular2/router'

import Ciao from './ciao'
import Hello from './hello'
import Linker from './linker'
import NavBar from './nav/navbar'

import { Greeter } from './services'

@Component({
  selector: 'master-app',
  viewProviders: [Greeter]
})
@View({
  directives: [ROUTER_DIRECTIVES, Linker, NavBar],
  template: `
  <div class="container">
    <nav class="navbar navbar-dark bg-inverse">
      <a class="navbar-brand" href="#">Mastering MEAN</a>
      <ul class="nav navbar-nav hidden-sm-down">
        <li class="nav-item">
          <a class="nav-link" href="#">Masters <span class="nv-alert">1</span></a>
        </li>
        <li class="nav-item">
          <a class="nav-link" href="#">Weapons <span class="nv-alert">15</span></a>
        </li>
        <li class="nav-item">
          <a class="nav-link" href="#">Ships</a>
        </li>
        <li class="nav-item">
          <a class="nav-link" href="#">About</a>
        </li>
      </ul>
      <ul class="nav navbar-nav pull-right">
        <li class="nav-item hidden-sm-down">
          <a class="nav-link" href="#">Login</a>
        </li>
        <li class="nav-item hidden-md-up">
          <button type="button" (click)="onClick()" class="btn btn-secondary-online"><i class="fa fa-bars"></i></button>
        </li>
      </ul>
    </nav>
    <div class="hidden-md-up">
      <h2 class="text-center">Full Stack Expert Javascript</h2>
    </div>
    <div class="hero hidden-sm-down">
      <h1 class="display-3">Mastering MEAN</h1>
      <p class="lead">Full Stack Expert Javascript</p>
    </div>

      <ul class="list-group hidden-md-up">
        <li class="list-group-item">
          <span class="label label-default label-pill pull-right">14</span>
          Jedi Masters
        </li>
        <li class="list-group-item">
          <span class="label label-default label-pill pull-right">2</span>
          Weapons
        </li>
        <li class="list-group-item">
          <span class="label label-default label-pill pull-right">1</span>
          Ships
        </li>
      </ul>

      <div class="card-deck home-sections hidden-sm-down">
        <div class="card yoda">
          <div class="card-img-top"></div>
          <div class="card-block">
            <h4 class="card-title">Jedi Masters</h4>
            <p class="card-text">This is a longer card with supporting text below as a natural lead-in to additional content. This content is a little bit longer.</p>
            <p class="card-text"><small class="text-muted">Last updated 3 mins ago</small></p>
          </div>
        </div>
        <div class="card weapons">
          <div class="card-img-top"></div>
          <div class="card-block">
            <h4 class="card-title">Weapons</h4>
            <p class="card-text">This card has supporting text below as a natural lead-in to additional content.</p>
            <p class="card-text"><small class="text-muted">Last updated 3 mins ago</small></p>
          </div>
        </div>
        <div class="card ships">
          <div class="card-img-top"></div>
          <div class="card-block">
            <h4 class="card-title">Ships</h4>
            <p class="card-text">This is a wider card with supporting text below as a natural lead-in to additional content. This card has even longer content than the first to show that equal height action.</p>
            <p class="card-text"><small class="text-muted">Last updated 3 mins ago</small></p>
          </div>
        </div>
      </div>

    <div class="row">
    <section class="new-jedi">
      <header>
        <h5><span class="highlight">New</span> Jedi</h5>
      </header>
      <div class="list-group list-group-lg">
        <div class="list-group-item">
         <p>Yoda</p>
        </div>
        <div class="list-group-item">
         <p>Obi Wan</p>
        </div>
        <div class="list-group-item">
         <p>Luke Skywalker</p>
        </div>
      </div>
    </section>

    <section class="new-logins">
      <header>
        <h5><span class="highlight">Lastest</span> Logins</h5>
      </header>
      <div class="list-group list-group-lg">
        <div class="list-group-item">
         <p>Darth Maul</p>
        </div>
        <div class="list-group-item">
         <p>Darth Vader</p>
        </div>
        <div class="list-group-item">
         <p>Senator Palpatine</p>
        </div>
      </div>
    </section>
    </div>

    <ul>
      <li><a [router-link]="['/Hello']">Hello</a></li>
      <li><a [router-link]="['/Ciao', { name: 'ng2' }]">Ciao</a></li>
    </ul>
    <router-outlet></router-outlet>
    <linker class="btn btn-sm" name="GitHub" url="https://github.com/northernv/master-mean"></linker>
  </div>
  `
})
@RouteConfig([
  new Route({ path: '/', component: Hello, name: 'Hello' }),
  new Route({ path: '/ciao/:name', component: Ciao, name: 'Ciao' })
])
class App {
}

bootstrap(App, [
  ROUTER_PROVIDERS,
  provide(ROUTER_PRIMARY_COMPONENT, {useValue: App}),
  provide(LocationStrategy, {useClass: HashLocationStrategy})
])
